@@ -1,7 +1,6 @@
-use askalono::{Store, TextData};
+use ::askalono::{Store, TextData};
 use pyo3::prelude::*;
 use pyo3::wrap_pyfunction;
-use pyo3::PyObjectProtocol;
 
 static CACHE_DATA: &[u8] = include_bytes!("../embedded-cache.bin.zstd");
 
@@ -17,23 +16,7 @@ struct License {
     name: String,
 }
 
-#[pyproto]
-impl PyObjectProtocol for License {
-    fn __str__(&self) -> PyResult<String> {
-        Ok(format!("{} {}", self.name, self.score))
-    }
-
-    fn __repr__(&self) -> PyResult<String> {
-        Ok(format!(
-            "License(name=\"{}\", score={})",
-            self.name, self.score
-        ))
-    }
-}
-
-// Identifies license based on its text
 #[pyfunction]
-#[text_signature = "(license_text, /)"]
 fn identify(license_text: &str) -> PyResult<License> {
     let store = load_store();
     let m = store.analyze(&TextData::from(license_text));
